from setuptools import setup, find_packages
 
classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='py-capsolver',
  version='0.0.3',
  description='capsolver wrappeer',
  url='',
  author='Slotth',
  author_email='slotth@outlook.com',
  classifiers=classifiers,
  keywords='capsolver', 
  packages=find_packages(),
  install_requires=[''] 
)